from enum import Enum


class SenmlUnit(Enum):
    METER = "m"
    KILOGRAM = "kg"
    GRAM = "g"
    SECOND = "s"
    AMPERE = "A"
    KELVIN = "K"
    CANDELA = "cd"
    MOLE = "mol"
    HERTZ = "Hz"
    RADIAN = "rad"
    STERADIAN = "sr"
    NEWTON = "N"
    PASCAL = "Pa"
    JOULE = "J"
    WATT = "W"
    COULOMB = "C"
    VOLT = "V"
    FARAD = "F"
    OHM = "Ohm"
    SIEMENS = "S"
    WEBER = "Wb"
    TESLA = "T"
    HENRY = "H"
    DEGREES_CELSIUS = "Cel"
    LUMEN = "lm"
    LUX = "lx"
    BECQUEREL = "Bq"
    GRAY = "Gy"
    SIEVERT = "Sv"
    KATAL = "kat"
    SQUARE_METER = "m2"
    CUBIC_METER = "m3"
    LITER = "l"
    VELOCITY = "m/s"
    ACCELERATION = "m/s2"
    CUBIC_METER_PER_SECOND = "m3/s"
    LITER_PER_SECOND = "l/s"
    WATT_PER_SQUARE_METER = "W/m2"
    CANDELA_PER_SQUARE_METER = "cd/m2"
    BIT = "bit"
    BIT_PER_SECOND = "bit/s"
    DEGREES_LATITUDE = "lat"
    DEGREES_LONGITUDE = "lon"
    PH = "pH"
    DECIBEL = "dB"
    DECIBEL_RELATIVE_TO_1_W = "dBW"
    BEL = "Bspl"
    COUNTER = "count"
    RATIO = "//"
    RELATIVE_HUMIDITY = "%RH"
    PERCENTAGE_REMAINING_BATTERY_LEVEL = "%EL"
    SECONDS_REMAINING_BATTERY_LEVEL = "EL"
    EVENT_RATE_PER_SECOND = "1/s"
    EVENT_RATE_PER_MINUTE = "1/min"
    BPM = "beat/min"
    BEATS = "beats"
    SIEMENS_PER_METER = "S/m"
    PERCENTAGE = "%"
